@@ -1,7 +1,8 @@
 /* -*- mode: C; c-file-style: "linux" -*- */
 
 /* MemProf -- memory profiler and leak detector
- * Copyright (C) 1999 Red Hat, Inc.
+ * Copyright 1999, 2000, 2001, Red Hat, Inc.
+ * Copyright 2002, Kristian Rietveld
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -560,7 +561,6 @@ leaks_find (MPProcess *process)
 		tmp_list = tmp_list->next;
 	}
 
- error:
 	/* Clean up
 	 */
 	g_list_free (clones);
@@ -568,9 +568,8 @@ leaks_find (MPProcess *process)
 	g_ptr_array_free (block_arr, TRUE);
 
 	close (memfd);
-	kill (process->pid, SIGCONT);
-
-	ptrace (PTRACE_DETACH, process->pid, 0, 0);
+	if (ptrace (PTRACE_DETACH, process->pid, 0, 0) == -1)
+		g_warning ("Detach failed %s (%d)\n", g_strerror (errno), errno);
 
 	return result;
 }
@@ -584,7 +583,9 @@ leaks_print (MPProcess *process, GSList *blocks, gchar *outfile)
 	out = fopen (outfile, "w");
 	if (!out)
 	{
-		show_error (ERROR_MODAL, _("Cannot open output file: %s\n"), g_strerror (errno));
+		show_error (NULL, ERROR_MODAL,
+			    _("Cannot open output file: %s\n"),
+			    g_strerror (errno));
 		return;
 	}
 
