@@ -1,7 +1,8 @@
 /* -*- mode: C; c-file-style: "linux" -*- */
 
 /* MemProf -- memory profiler and leak detector
- * Copyright (C) 1999 Red Hat, Inc.
+ * Copyright 1999, 2000, 2001, Red Hat, Inc.
+ * Copyright 2002, Kristian Rietveld
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +21,7 @@
 /*====*/
 
 #include <glib.h>
+#include <gtk/gtkwidget.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include "bfd.h"
@@ -69,9 +71,10 @@ typedef enum {
   ERROR_FATAL
 } ErrorType;
 
-void show_error	(ErrorType error,
+void show_error	(GtkWidget *parent_window,
+		 ErrorType error,
 		 const gchar *format,
-		 ...) G_GNUC_PRINTF (2, 3);
+		 ...) G_GNUC_PRINTF (3, 4);
 
 void     process_map_sections (Map           *map,
 			       SectionFunc    func,
