@@ -1,7 +1,8 @@
 /* -*- mode: C; c-file-style: "linux" -*- */
 
 /* MemProf -- memory profiler and leak detector
- * Copyright (C) 1999 Red Hat, Inc.
+ * Copyright 1999, 2000, 2001, Red Hat, Inc.
+ * Copyright 2002, Kristian Rietveld
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -124,18 +125,19 @@ compare_function (const void *a, const void *b)
 }
 
 Profile *
-profile_create (MPProcess *process, char **skip_funcs, gint n_skip_funcs)
+profile_create (MPProcess *process,
+		GSList *skip_funcs)
 {
   GArray *functions;
   Profile *profile;
-  int i;
+  GSList *tmp_list;
 
   profile = g_new (Profile, 1);
   profile->process = process;
   
   profile->skip_hash = g_hash_table_new (g_str_hash, g_str_equal);
-  for (i=0; i<n_skip_funcs; i++)
-    g_hash_table_insert (profile->skip_hash, skip_funcs[i], "");
+  for (tmp_list = skip_funcs; tmp_list != NULL; tmp_list = tmp_list->next)
+    g_hash_table_insert (profile->skip_hash, (gchar *)tmp_list->data, "");
   
   /* Go through all blocks, and add up memory
    */
@@ -177,6 +179,15 @@ print_refs (FILE *out, GList *reflist)
     }
 }
 
+static gint
+refs_compare (const void *a, const void *b)
+{
+  const ProfileFuncRef *refa = a;
+  const ProfileFuncRef *refb = b;
+
+  return strcmp (refa->function->symbol->name, refb->function->symbol->name);
+}
+
 void
 profile_write (Profile *profile, gchar *outfile)
 {
@@ -189,7 +200,8 @@ profile_write (Profile *profile, gchar *outfile)
   out = fopen (outfile, "w");
   if (!out)
     {
-      show_error (ERROR_MODAL, _("Cannot open output file: %s\n"), g_strerror (errno));
+      show_error (NULL, ERROR_MODAL, _("Cannot open output file: %s\n"),
+		  g_strerror (errno));
       return;
     }
   
@@ -197,10 +209,12 @@ profile_write (Profile *profile, gchar *outfile)
     {
       fprintf (out, "%s\n", profile->functions[i]->symbol->name);
       fprintf (out, "  children:\n");
+      profile->functions[i]->children = g_list_sort (profile->functions[i]->children, refs_compare);
       print_refs (out, profile->functions[i]->children);
       fprintf (out, "  total: %d\n", profile->functions[i]->total);
       fprintf (out, "  self:  %d\n", profile->functions[i]->self);
       fprintf (out, "  inherited:\n");
+      profile->functions[i]->inherited = g_list_sort (profile->functions[i]->inherited, refs_compare);
       print_refs (out, profile->functions[i]->inherited);
       
       fprintf (out, "\n");
@@ -217,7 +231,9 @@ profile_free (Profile *profile)
   for (i=0; i<profile->n_functions; i++)
     {
       g_list_foreach (profile->functions[i]->children, (GFunc)g_free, NULL);
+      g_list_free (profile->functions[i]->children);
       g_list_foreach (profile->functions[i]->inherited, (GFunc)g_free, NULL);
+      g_list_free (profile->functions[i]->inherited);
       g_free (profile->functions[i]);
     }
 
